@@ -43,7 +43,7 @@ WWW::PipeViewer - A simple interface to YouTube.
 
 =cut
 
-our $VERSION = '0.5.0';
+our $VERSION = '0.5.3';
 
 =head1 SYNOPSIS
 
@@ -331,11 +331,13 @@ sub set_lwp_useragent {
     };
 
     $agent->ssl_opts(Timeout => $self->get_timeout);
-    $agent->default_header('Accept-Encoding'           => $accepted_encodings);
-    $agent->default_header('Accept'                    => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8');
-    $agent->default_header('Accept-Language'           => 'en-US,en;q=0.5');
-    $agent->default_header('Connection'                => 'keep-alive');
-    $agent->default_header('Upgrade-Insecure-Requests' => '1');
+    $agent->default_header(
+                           'Accept-Encoding'           => $accepted_encodings,
+                           'Accept'                    => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
+                           'Accept-Language'           => 'en-US,en;q=0.5',
+                           'Connection'                => 'keep-alive',
+                           'Upgrade-Insecure-Requests' => '1'
+                          );
     $agent->proxy(['http', 'https'], $self->get_http_proxy) if defined($self->get_http_proxy);
 
     my $cookie_file = $self->get_cookie_file;
@@ -386,6 +388,9 @@ sub set_lwp_useragent {
                              "/", ".youtube.com", undef, 0, 1, "17" . join('', map { int(rand(10)) } 1 .. 8),
                              0, {});
 
+        my $rand_value = '17' . join('', map { int(rand(10)) } 1 .. 8);
+        $cookies->set_cookie(0, "SOCS", "CAI", "/", ".youtube.com", undef, 0, 1, $rand_value, 0, {});
+
         $agent->cookie_jar($cookies);
     }
 
