@@ -137,6 +137,8 @@ sub get_itags {
                   {value => 612, format => 'webm', split => 1, hfr => 1},              # vp9 hls HFR (v)
                   {value => 609, format => 'webm', split => 1},                        # vp9 hls (v)
                   {value => 634, format => 'webm', split => 1},                        # vp9 hls (v)
+                  {value => 780, format => 'webm', split => 1},                        # vp9 (v)
+                  {value => 779, format => 'webm', split => 1},                        # vp9 (v)
                  ],
 
         '360' => [{value => 243, format => 'webm', split => 1},                        # webm (v)
@@ -196,6 +198,7 @@ sub get_itags {
             {value => 328, format => 'm4a',  kbps => 384},                       # eac3 (384 kbps)
             {value => 380, format => 'm4a',  kbps => 384},                       # ac3 (384 kbps)
             {value => 258, format => 'm4a',  kbps => 360},                       # mp4a (360 kbps?)
+            {value => 774, format => 'opus', kbps => 260},                       # webm opus (260 kbps)
             {value => 172, format => 'opus', kbps => 192},                       # webm opus (192 kbps)
             {value => 251, format => 'opus', kbps => 160},                       # webm opus (128-160 kbps)
             {value => 171, format => 'webm', kbps => 128},                       # webm vorbis (92-128 kbps)
@@ -225,6 +228,7 @@ sub get_itags {
             {value => '140-drc', format => 'm4a',  kbps => 128},                 # mp4a (128 kbps)
             {value => '250-drc', format => 'opus', kbps => 64},                  # webm opus (64 kbps)
             {value => '249-drc', format => 'opus', kbps => 48},                  # webm opus (48 kbps)
+            {value => '139-drc', format => 'm4a',  kbps => 48},                  # mp4a (48kbps)
         ],
 
         'dash' => [{value => '133-dash', format => 'mp4'},                              # mp4 DASH (v-a)
